@@ -33,9 +33,10 @@
 #  define SONNETCORE_DEPRECATED_NO_EXPORT SONNETCORE_NO_EXPORT SONNETCORE_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define SONNETCORE_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef SONNETCORE_NO_DEPRECATED
+#    define SONNETCORE_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
