@@ -33,9 +33,10 @@
 #  define SONNETUI_DEPRECATED_NO_EXPORT SONNETUI_NO_EXPORT SONNETUI_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define SONNETUI_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef SONNETUI_NO_DEPRECATED
+#    define SONNETUI_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
